DEF = "urn:mace:dir:attribute-def:"


MAP = {
    "identifier": "urn:oasis:names:tc:SAML:2.0:attrname-format:basic",
    "fro": {
        f"{DEF}aRecord": "aRecord",
        f"{DEF}aliasedEntryName": "aliasedEntryName",
        f"{DEF}aliasedObjectName": "aliasedObjectName",
        f"{DEF}associatedDomain": "associatedDomain",
        f"{DEF}associatedName": "associatedName",
        f"{DEF}audio": "audio",
        f"{DEF}authorityRevocationList": "authorityRevocationList",
        f"{DEF}buildingName": "buildingName",
        f"{DEF}businessCategory": "businessCategory",
        f"{DEF}c": "c",
        f"{DEF}cACertificate": "cACertificate",
        f"{DEF}cNAMERecord": "cNAMERecord",
        f"{DEF}carLicense": "carLicense",
        f"{DEF}certificateRevocationList": "certificateRevocationList",
        f"{DEF}cn": "cn",
        f"{DEF}co": "co",
        f"{DEF}commonName": "commonName",
        f"{DEF}countryName": "countryName",
        f"{DEF}crossCertificatePair": "crossCertificatePair",
        f"{DEF}dITRedirect": "dITRedirect",
        f"{DEF}dSAQuality": "dSAQuality",
        f"{DEF}dc": "dc",
        f"{DEF}deltaRevocationList": "deltaRevocationList",
        f"{DEF}departmentNumber": "departmentNumber",
        f"{DEF}description": "description",
        f"{DEF}destinationIndicator": "destinationIndicator",
        f"{DEF}displayName": "displayName",
        f"{DEF}distinguishedName": "distinguishedName",
        f"{DEF}dmdName": "dmdName",
        f"{DEF}dnQualifier": "dnQualifier",
        f"{DEF}documentAuthor": "documentAuthor",
        f"{DEF}documentIdentifier": "documentIdentifier",
        f"{DEF}documentLocation": "documentLocation",
        f"{DEF}documentPublisher": "documentPublisher",
        f"{DEF}documentTitle": "documentTitle",
        f"{DEF}documentVersion": "documentVersion",
        f"{DEF}domainComponent": "domainComponent",
        f"{DEF}drink": "drink",
        f"{DEF}eduOrgHomePageURI": "eduOrgHomePageURI",
        f"{DEF}eduOrgIdentityAuthNPolicyURI": "eduOrgIdentityAuthNPolicyURI",
        f"{DEF}eduOrgLegalName": "eduOrgLegalName",
        f"{DEF}eduOrgSuperiorURI": "eduOrgSuperiorURI",
        f"{DEF}eduOrgWhitePagesURI": "eduOrgWhitePagesURI",
        f"{DEF}eduCourseOffering": "eduCourseOffering",
        f"{DEF}eduCourseMember": "eduCourseMember",
        f"{DEF}eduPersonAffiliation": "eduPersonAffiliation",
        f"{DEF}eduPersonEntitlement": "eduPersonEntitlement",
        f"{DEF}eduPersonNickname": "eduPersonNickname",
        f"{DEF}eduPersonOrgDN": "eduPersonOrgDN",
        f"{DEF}eduPersonOrgUnitDN": "eduPersonOrgUnitDN",
        f"{DEF}eduPersonPrimaryAffiliation": "eduPersonPrimaryAffiliation",
        f"{DEF}eduPersonPrimaryOrgUnitDN": "eduPersonPrimaryOrgUnitDN",
        f"{DEF}eduPersonPrincipalName": "eduPersonPrincipalName",
        f"{DEF}eduPersonPrincipalNamePrior": "eduPersonPrincipalNamePrior",
        f"{DEF}eduPersonScopedAffiliation": "eduPersonScopedAffiliation",
        f"{DEF}eduPersonTargetedID": "eduPersonTargetedID",
        f"{DEF}eduPersonAssurance": "eduPersonAssurance",
        f"{DEF}eduPersonUniqueId": "eduPersonUniqueId",
        f"{DEF}eduPersonOrcid": "eduPersonOrcid",
        f"{DEF}email": "email",
        f"{DEF}emailAddress": "emailAddress",
        f"{DEF}employeeNumber": "employeeNumber",
        f"{DEF}employeeType": "employeeType",
        f"{DEF}enhancedSearchGuide": "enhancedSearchGuide",
        f"{DEF}facsimileTelephoneNumber": "facsimileTelephoneNumber",
        f"{DEF}favouriteDrink": "favouriteDrink",
        f"{DEF}fax": "fax",
        f"{DEF}federationFeideSchemaVersion": "federationFeideSchemaVersion",
        f"{DEF}friendlyCountryName": "friendlyCountryName",
        f"{DEF}generationQualifier": "generationQualifier",
        f"{DEF}givenName": "givenName",
        f"{DEF}gn": "gn",
        f"{DEF}homePhone": "homePhone",
        f"{DEF}homePostalAddress": "homePostalAddress",
        f"{DEF}homeTelephoneNumber": "homeTelephoneNumber",
        f"{DEF}host": "host",
        f"{DEF}houseIdentifier": "houseIdentifier",
        f"{DEF}info": "info",
        f"{DEF}initials": "initials",
        f"{DEF}internationaliSDNNumber": "internationaliSDNNumber",
        f"{DEF}isMemberOf": "isMemberOf",
        f"{DEF}janetMailbox": "janetMailbox",
        f"{DEF}jpegPhoto": "jpegPhoto",
        f"{DEF}knowledgeInformation": "knowledgeInformation",
        f"{DEF}l": "l",
        f"{DEF}labeledURI": "labeledURI",
        f"{DEF}localityName": "localityName",
        f"{DEF}mDRecord": "mDRecord",
        f"{DEF}mXRecord": "mXRecord",
        f"{DEF}mail": "mail",
        f"{DEF}mailPreferenceOption": "mailPreferenceOption",
        f"{DEF}manager": "manager",
        f"{DEF}member": "member",
        f"{DEF}mobile": "mobile",
        f"{DEF}mobileTelephoneNumber": "mobileTelephoneNumber",
        f"{DEF}nSRecord": "nSRecord",
        f"{DEF}name": "name",
        f"{DEF}norEduOrgAcronym": "norEduOrgAcronym",
        f"{DEF}norEduOrgNIN": "norEduOrgNIN",
        f"{DEF}norEduOrgSchemaVersion": "norEduOrgSchemaVersion",
        f"{DEF}norEduOrgUniqueIdentifier": "norEduOrgUniqueIdentifier",
        f"{DEF}norEduOrgUniqueNumber": "norEduOrgUniqueNumber",
        f"{DEF}norEduOrgUnitUniqueIdentifier": "norEduOrgUnitUniqueIdentifier",
        f"{DEF}norEduOrgUnitUniqueNumber": "norEduOrgUnitUniqueNumber",
        f"{DEF}norEduPersonBirthDate": "norEduPersonBirthDate",
        f"{DEF}norEduPersonLIN": "norEduPersonLIN",
        f"{DEF}norEduPersonNIN": "norEduPersonNIN",
        f"{DEF}o": "o",
        f"{DEF}objectClass": "objectClass",
        f"{DEF}organizationName": "organizationName",
        f"{DEF}organizationalStatus": "organizationalStatus",
        f"{DEF}organizationalUnitName": "organizationalUnitName",
        f"{DEF}otherMailbox": "otherMailbox",
        f"{DEF}ou": "ou",
        f"{DEF}owner": "owner",
        f"{DEF}pager": "pager",
        f"{DEF}pagerTelephoneNumber": "pagerTelephoneNumber",
        f"{DEF}personalSignature": "personalSignature",
        f"{DEF}personalTitle": "personalTitle",
        f"{DEF}photo": "photo",
        f"{DEF}physicalDeliveryOfficeName": "physicalDeliveryOfficeName",
        f"{DEF}pkcs9email": "pkcs9email",
        f"{DEF}postOfficeBox": "postOfficeBox",
        f"{DEF}postalAddress": "postalAddress",
        f"{DEF}postalCode": "postalCode",
        f"{DEF}preferredDeliveryMethod": "preferredDeliveryMethod",
        f"{DEF}preferredLanguage": "preferredLanguage",
        f"{DEF}presentationAddress": "presentationAddress",
        f"{DEF}protocolInformation": "protocolInformation",
        f"{DEF}pseudonym": "pseudonym",
        f"{DEF}registeredAddress": "registeredAddress",
        f"{DEF}rfc822Mailbox": "rfc822Mailbox",
        f"{DEF}roleOccupant": "roleOccupant",
        f"{DEF}roomNumber": "roomNumber",
        f"{DEF}sOARecord": "sOARecord",
        f"{DEF}searchGuide": "searchGuide",
        f"{DEF}secretary": "secretary",
        f"{DEF}seeAlso": "seeAlso",
        f"{DEF}serialNumber": "serialNumber",
        f"{DEF}singleLevelQuality": "singleLevelQuality",
        f"{DEF}sn": "sn",
        f"{DEF}st": "st",
        f"{DEF}stateOrProvinceName": "stateOrProvinceName",
        f"{DEF}street": "street",
        f"{DEF}streetAddress": "streetAddress",
        f"{DEF}subtreeMaximumQuality": "subtreeMaximumQuality",
        f"{DEF}subtreeMinimumQuality": "subtreeMinimumQuality",
        f"{DEF}supportedAlgorithms": "supportedAlgorithms",
        f"{DEF}supportedApplicationContext": "supportedApplicationContext",
        f"{DEF}surname": "surname",
        f"{DEF}telephoneNumber": "telephoneNumber",
        f"{DEF}teletexTerminalIdentifier": "teletexTerminalIdentifier",
        f"{DEF}telexNumber": "telexNumber",
        f"{DEF}textEncodedORAddress": "textEncodedORAddress",
        f"{DEF}title": "title",
        f"{DEF}uid": "uid",
        f"{DEF}uniqueIdentifier": "uniqueIdentifier",
        f"{DEF}uniqueMember": "uniqueMember",
        f"{DEF}userCertificate": "userCertificate",
        f"{DEF}userClass": "userClass",
        f"{DEF}userPKCS12": "userPKCS12",
        f"{DEF}userPassword": "userPassword",
        f"{DEF}userSMIMECertificate": "userSMIMECertificate",
        f"{DEF}userid": "userid",
        f"{DEF}x121Address": "x121Address",
        f"{DEF}x500UniqueIdentifier": "x500UniqueIdentifier",
    },
    "to": {
        "aRecord": f"{DEF}aRecord",
        "aliasedEntryName": f"{DEF}aliasedEntryName",
        "aliasedObjectName": f"{DEF}aliasedObjectName",
        "associatedDomain": f"{DEF}associatedDomain",
        "associatedName": f"{DEF}associatedName",
        "audio": f"{DEF}audio",
        "authorityRevocationList": f"{DEF}authorityRevocationList",
        "buildingName": f"{DEF}buildingName",
        "businessCategory": f"{DEF}businessCategory",
        "c": f"{DEF}c",
        "cACertificate": f"{DEF}cACertificate",
        "cNAMERecord": f"{DEF}cNAMERecord",
        "carLicense": f"{DEF}carLicense",
        "certificateRevocationList": f"{DEF}certificateRevocationList",
        "cn": f"{DEF}cn",
        "co": f"{DEF}co",
        "commonName": f"{DEF}commonName",
        "countryName": f"{DEF}countryName",
        "crossCertificatePair": f"{DEF}crossCertificatePair",
        "dITRedirect": f"{DEF}dITRedirect",
        "dSAQuality": f"{DEF}dSAQuality",
        "dc": f"{DEF}dc",
        "deltaRevocationList": f"{DEF}deltaRevocationList",
        "departmentNumber": f"{DEF}departmentNumber",
        "description": f"{DEF}description",
        "destinationIndicator": f"{DEF}destinationIndicator",
        "displayName": f"{DEF}displayName",
        "distinguishedName": f"{DEF}distinguishedName",
        "dmdName": f"{DEF}dmdName",
        "dnQualifier": f"{DEF}dnQualifier",
        "documentAuthor": f"{DEF}documentAuthor",
        "documentIdentifier": f"{DEF}documentIdentifier",
        "documentLocation": f"{DEF}documentLocation",
        "documentPublisher": f"{DEF}documentPublisher",
        "documentTitle": f"{DEF}documentTitle",
        "documentVersion": f"{DEF}documentVersion",
        "domainComponent": f"{DEF}domainComponent",
        "drink": f"{DEF}drink",
        "eduOrgHomePageURI": f"{DEF}eduOrgHomePageURI",
        "eduOrgIdentityAuthNPolicyURI": f"{DEF}eduOrgIdentityAuthNPolicyURI",
        "eduOrgLegalName": f"{DEF}eduOrgLegalName",
        "eduOrgSuperiorURI": f"{DEF}eduOrgSuperiorURI",
        "eduOrgWhitePagesURI": f"{DEF}eduOrgWhitePagesURI",
        "eduCourseMember": f"{DEF}eduCourseMember",
        "eduCourseOffering": f"{DEF}eduCourseOffering",
        "eduPersonAffiliation": f"{DEF}eduPersonAffiliation",
        "eduPersonEntitlement": f"{DEF}eduPersonEntitlement",
        "eduPersonNickname": f"{DEF}eduPersonNickname",
        "eduPersonOrgDN": f"{DEF}eduPersonOrgDN",
        "eduPersonOrgUnitDN": f"{DEF}eduPersonOrgUnitDN",
        "eduPersonPrimaryAffiliation": f"{DEF}eduPersonPrimaryAffiliation",
        "eduPersonPrimaryOrgUnitDN": f"{DEF}eduPersonPrimaryOrgUnitDN",
        "eduPersonPrincipalName": f"{DEF}eduPersonPrincipalName",
        "eduPersonPrincipalNamePrior": f"{DEF}eduPersonPrincipalNamePrior",
        "eduPersonScopedAffiliation": f"{DEF}eduPersonScopedAffiliation",
        "eduPersonTargetedID": f"{DEF}eduPersonTargetedID",
        "eduPersonAssurance": f"{DEF}eduPersonAssurance",
        "eduPersonUniqueId": f"{DEF}eduPersonUniqueId",
        "eduPersonOrcid": f"{DEF}eduPersonOrcid",
        "email": f"{DEF}email",
        "emailAddress": f"{DEF}emailAddress",
        "employeeNumber": f"{DEF}employeeNumber",
        "employeeType": f"{DEF}employeeType",
        "enhancedSearchGuide": f"{DEF}enhancedSearchGuide",
        "facsimileTelephoneNumber": f"{DEF}facsimileTelephoneNumber",
        "favouriteDrink": f"{DEF}favouriteDrink",
        "fax": f"{DEF}fax",
        "federationFeideSchemaVersion": f"{DEF}federationFeideSchemaVersion",
        "friendlyCountryName": f"{DEF}friendlyCountryName",
        "generationQualifier": f"{DEF}generationQualifier",
        "givenName": f"{DEF}givenName",
        "gn": f"{DEF}gn",
        "homePhone": f"{DEF}homePhone",
        "homePostalAddress": f"{DEF}homePostalAddress",
        "homeTelephoneNumber": f"{DEF}homeTelephoneNumber",
        "host": f"{DEF}host",
        "houseIdentifier": f"{DEF}houseIdentifier",
        "info": f"{DEF}info",
        "initials": f"{DEF}initials",
        "internationaliSDNNumber": f"{DEF}internationaliSDNNumber",
        "isMemberOf": f"{DEF}isMemberOf",
        "janetMailbox": f"{DEF}janetMailbox",
        "jpegPhoto": f"{DEF}jpegPhoto",
        "knowledgeInformation": f"{DEF}knowledgeInformation",
        "l": f"{DEF}l",
        "labeledURI": f"{DEF}labeledURI",
        "localityName": f"{DEF}localityName",
        "mDRecord": f"{DEF}mDRecord",
        "mXRecord": f"{DEF}mXRecord",
        "mail": f"{DEF}mail",
        "mailPreferenceOption": f"{DEF}mailPreferenceOption",
        "manager": f"{DEF}manager",
        "member": f"{DEF}member",
        "mobile": f"{DEF}mobile",
        "mobileTelephoneNumber": f"{DEF}mobileTelephoneNumber",
        "nSRecord": f"{DEF}nSRecord",
        "name": f"{DEF}name",
        "norEduOrgAcronym": f"{DEF}norEduOrgAcronym",
        "norEduOrgNIN": f"{DEF}norEduOrgNIN",
        "norEduOrgSchemaVersion": f"{DEF}norEduOrgSchemaVersion",
        "norEduOrgUniqueIdentifier": f"{DEF}norEduOrgUniqueIdentifier",
        "norEduOrgUniqueNumber": f"{DEF}norEduOrgUniqueNumber",
        "norEduOrgUnitUniqueIdentifier": f"{DEF}norEduOrgUnitUniqueIdentifier",
        "norEduOrgUnitUniqueNumber": f"{DEF}norEduOrgUnitUniqueNumber",
        "norEduPersonBirthDate": f"{DEF}norEduPersonBirthDate",
        "norEduPersonLIN": f"{DEF}norEduPersonLIN",
        "norEduPersonNIN": f"{DEF}norEduPersonNIN",
        "o": f"{DEF}o",
        "objectClass": f"{DEF}objectClass",
        "organizationName": f"{DEF}organizationName",
        "organizationalStatus": f"{DEF}organizationalStatus",
        "organizationalUnitName": f"{DEF}organizationalUnitName",
        "otherMailbox": f"{DEF}otherMailbox",
        "ou": f"{DEF}ou",
        "owner": f"{DEF}owner",
        "pager": f"{DEF}pager",
        "pagerTelephoneNumber": f"{DEF}pagerTelephoneNumber",
        "personalSignature": f"{DEF}personalSignature",
        "personalTitle": f"{DEF}personalTitle",
        "photo": f"{DEF}photo",
        "physicalDeliveryOfficeName": f"{DEF}physicalDeliveryOfficeName",
        "pkcs9email": f"{DEF}pkcs9email",
        "postOfficeBox": f"{DEF}postOfficeBox",
        "postalAddress": f"{DEF}postalAddress",
        "postalCode": f"{DEF}postalCode",
        "preferredDeliveryMethod": f"{DEF}preferredDeliveryMethod",
        "preferredLanguage": f"{DEF}preferredLanguage",
        "presentationAddress": f"{DEF}presentationAddress",
        "protocolInformation": f"{DEF}protocolInformation",
        "pseudonym": f"{DEF}pseudonym",
        "registeredAddress": f"{DEF}registeredAddress",
        "rfc822Mailbox": f"{DEF}rfc822Mailbox",
        "roleOccupant": f"{DEF}roleOccupant",
        "roomNumber": f"{DEF}roomNumber",
        "sOARecord": f"{DEF}sOARecord",
        "searchGuide": f"{DEF}searchGuide",
        "secretary": f"{DEF}secretary",
        "seeAlso": f"{DEF}seeAlso",
        "serialNumber": f"{DEF}serialNumber",
        "singleLevelQuality": f"{DEF}singleLevelQuality",
        "sn": f"{DEF}sn",
        "st": f"{DEF}st",
        "stateOrProvinceName": f"{DEF}stateOrProvinceName",
        "street": f"{DEF}street",
        "streetAddress": f"{DEF}streetAddress",
        "subtreeMaximumQuality": f"{DEF}subtreeMaximumQuality",
        "subtreeMinimumQuality": f"{DEF}subtreeMinimumQuality",
        "supportedAlgorithms": f"{DEF}supportedAlgorithms",
        "supportedApplicationContext": f"{DEF}supportedApplicationContext",
        "surname": f"{DEF}surname",
        "telephoneNumber": f"{DEF}telephoneNumber",
        "teletexTerminalIdentifier": f"{DEF}teletexTerminalIdentifier",
        "telexNumber": f"{DEF}telexNumber",
        "textEncodedORAddress": f"{DEF}textEncodedORAddress",
        "title": f"{DEF}title",
        "uid": f"{DEF}uid",
        "uniqueIdentifier": f"{DEF}uniqueIdentifier",
        "uniqueMember": f"{DEF}uniqueMember",
        "userCertificate": f"{DEF}userCertificate",
        "userClass": f"{DEF}userClass",
        "userPKCS12": f"{DEF}userPKCS12",
        "userPassword": f"{DEF}userPassword",
        "userSMIMECertificate": f"{DEF}userSMIMECertificate",
        "userid": f"{DEF}userid",
        "x121Address": f"{DEF}x121Address",
        "x500UniqueIdentifier": f"{DEF}x500UniqueIdentifier",
    },
}
